@@ -19,7 +19,7 @@
 
 #ifndef PACKAGETEST_H
 
-#include <QtTest/QtTest>
+#include <QTest>
 
 #include "kpackage/package.h"
 #include "kpackage/packagestructure.h"
@@ -36,6 +36,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void createAndInstallPackage();
     void createAndUpdatePackage();
+    void uncompressPackageWithSubFolder();
     void isValid();
     void filePath();
     void entryList();
